import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom'; 
import { select, axisleft, axisBottom, csv, arc, pie, scaleBand, scaleLinear } from 'd3';

const csvUrl =
    "https://gist.githubusercontent.com/Karnisrikanth/a27f195b689f4b1ae4b79fc676c8ca63/raw/e041d0943da7e58cb5f6b7cd44a378b4bd8ab8eb/cities_data.csv";
const width   = 960;
const height  = 500;
const margin  = { top: 20, right: 20, bottom: 50, left: 200 };

const App = () => {
  const [data, setData] = useState(null);
  
  useEffect(() => {
    const row = d => {
      d.basic_cost = d['basic_cost']; 
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 15));
    });
  }, []);
   
  if (!data) { 
    return <pre>Loading...</pre>;
  }
  
  const innerHeight = height -  margin.top - margin.bottom - 100;
  const innerwidth  = width - margin.left - margin.right;
  
  const yScale = scaleBand()
    .domain(data.map(d => d.country)) 
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.basic_cost)])
    .range([0, innerWidth]);
  
  return (
    <svg width ={width} height = {height}>
      <g transform ={'translate(${margin.left}, ${margin, top})'}>
        {xScale.ticks().map(tickValue => {
          <g key={tickValue} transform= {'translate(${xScale(tickValue)},0)'}>
            <line y2={innerHeight} stroke="blue" />
            <text
              styles = {{textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        })}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32cm" 
            y={yScale(tickValue) + yScale.bandwidth() /2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key= {d.country}
            x={0}
            y={yScale(d.country)}
            width={xScale(d.basic_cost)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>                       
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
